<p align="center">
  <img src="https://i.imgur.com/kc7aE7z.png" width="600">
   <b>
    <center> <h1>scivision: A toolkit for scientific image analysis</h1> </center>
   </b>
</p>

[![scivision](https://github.com/alan-turing-institute/scivision/actions/workflows/scivision.yml/badge.svg)](https://github.com/alan-turing-institute/scivision/actions/workflows/scivision.yml) [![Documentation Status](https://readthedocs.org/projects/scivision/badge/?version=latest)](https://scivision.readthedocs.io/en/latest/?badge=latest)

## Mission statement 
`scivision` aims to be a well-documented and generalisable python framework for applying computer vision methods to a wide range of scientific imagery.

This tool aims to foster collaboration between **data owners** and **developers** by:
* Empowering scientific domain experts to easily access and integrate the latest CV tools
* Enabling algorithm developers to distribute their tools to users across scientific fields
* Evolving with a focus on the needs and priorities of both developers and users
* Creating and maintaining a community of interdisciplinary contributors
* Providing a bridge between different data scales and formats
